@@ -1,4 +1,4 @@
-/* $Id: engine.c 4711 2004-11-01 16:10:55Z benny $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2003-2004 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
@@ -33,15 +33,19 @@
 #define DEFAULT_THEME   "Default"
 
 
+G_MODULE_EXPORT void engine_init (XfsmSplashEngine *engine);
+
+
 static void
 engine_setup (XfsmSplashEngine *engine,
               XfsmSplashRc     *rc)
 {
-  const gchar *theme_name;
-  BalouTheme  *theme;
+  gchar      *theme_name;
+  BalouTheme *theme;
 
   theme_name = xfsm_splash_rc_read_entry (rc, "Theme", DEFAULT_THEME);
   theme = balou_theme_load (theme_name);
+  g_free (theme_name);
 
   balou_init (BALOU (engine->user_data),
               engine->display,
