@@ -7,12 +7,12 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- *                                                                              
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *                                                                              
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
@@ -32,20 +32,18 @@
 
 #include "xfae-model.h"
 
-
+#include <libxfce4ui/libxfce4ui.h>
 
 typedef struct _XfaeItem XfaeItem;
 
 
 
-static void               xfae_model_class_init       (XfaeModelClass     *klass);
-static void               xfae_model_init             (XfaeModel          *model);
 static void               xfae_model_tree_model_init  (GtkTreeModelIface  *iface);
 static void               xfae_model_finalize         (GObject            *object);
 static GtkTreeModelFlags  xfae_model_get_flags        (GtkTreeModel       *tree_model);
 static gint               xfae_model_get_n_columns    (GtkTreeModel       *tree_model);
 static GType              xfae_model_get_column_type  (GtkTreeModel       *tree_model,
-                                                       gint                index);
+                                                       gint                index_);
 static gboolean           xfae_model_get_iter         (GtkTreeModel       *tree_model,
                                                        GtkTreeIter        *iter,
                                                        GtkTreePath        *path);
@@ -87,7 +85,7 @@ struct _XfaeModel
 {
   GObject __parent__;
 
-  guint  stamp;
+  gint   stamp;
   GList *items;
 };
 
@@ -193,9 +191,9 @@ xfae_model_get_n_columns (GtkTreeModel *tree_model)
 
 static GType
 xfae_model_get_column_type (GtkTreeModel *tree_model,
-                            gint          index)
+                            gint          index_)
 {
-  switch (index)
+  switch (index_)
     {
     case XFAE_MODEL_COLUMN_NAME:
       return G_TYPE_STRING;
@@ -222,17 +220,17 @@ xfae_model_get_iter (GtkTreeModel *tree_model,
                      GtkTreePath  *path)
 {
   XfaeModel *model = XFAE_MODEL (tree_model);
-  gint       index;
+  guint      index_;
 
   g_return_val_if_fail (XFAE_IS_MODEL (model), FALSE);
   g_return_val_if_fail (gtk_tree_path_get_depth (path) > 0, FALSE);
 
-  index = gtk_tree_path_get_indices (path)[0];
-  if (G_UNLIKELY (index >= g_list_length (model->items)))
+  index_ = gtk_tree_path_get_indices (path)[0];
+  if (G_UNLIKELY (index_ >= g_list_length (model->items)))
     return FALSE;
 
   iter->stamp = model->stamp;
-  iter->user_data = g_list_nth (model->items, index);
+  iter->user_data = g_list_nth (model->items, index_);
 
   return TRUE;
 }
@@ -244,16 +242,16 @@ xfae_model_get_path (GtkTreeModel *tree_model,
                      GtkTreeIter  *iter)
 {
   XfaeModel *model = XFAE_MODEL (tree_model);
-  gint       index;
+  gint       index_;
 
   g_return_val_if_fail (XFAE_IS_MODEL (model), NULL);
   g_return_val_if_fail (model->stamp == iter->stamp, NULL);
 
-  index = g_list_position (model->items, iter->user_data);
-  if (G_UNLIKELY (index < 0))
+  index_ = g_list_position (model->items, iter->user_data);
+  if (G_UNLIKELY (index_ < 0))
     return NULL;
 
-  return gtk_tree_path_new_from_indices (index, -1);
+  return gtk_tree_path_new_from_indices (index_, -1);
 }
 
 
@@ -373,7 +371,7 @@ xfae_model_iter_nth_child (GtkTreeModel *tree_model,
 
   g_return_val_if_fail (XFAE_IS_MODEL (model), FALSE);
 
-  if (G_UNLIKELY (parent == NULL && n < g_list_length (model->items)))
+  if (G_UNLIKELY (parent == NULL && n < (gint)g_list_length (model->items)))
     {
       iter->stamp = model->stamp;
       iter->user_data = g_list_nth (model->items, n);
@@ -408,6 +406,7 @@ xfae_item_new (const gchar *relpath)
   gchar      **args;
   gchar       *icon_name;
   gint         m;
+  GtkIconTheme *icon_theme;
 
   rc = xfce_rc_config_open (XFCE_RESOURCE_CONFIG, relpath, TRUE);
   if (G_LIKELY (rc != NULL))
@@ -418,6 +417,8 @@ xfae_item_new (const gchar *relpath)
       value = xfce_rc_read_entry (rc, "Type", NULL);
       if (G_LIKELY (value != NULL && g_ascii_strcasecmp (value, "Application") == 0))
         {
+          icon_theme = gtk_icon_theme_get_default ();
+
           item = g_new0 (XfaeItem, 1);
           item->relpath = g_strdup (relpath);
 
@@ -427,7 +428,7 @@ xfae_item_new (const gchar *relpath)
 
           value = xfce_rc_read_entry (rc, "Icon", NULL);
           if (G_UNLIKELY (value != NULL))
-            item->icon = xfce_themed_icon_load (value, 16);
+            item->icon = gtk_icon_theme_load_icon (icon_theme, value, 16, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
           else
             {
               /* we try to be smart here in that we try to guess
@@ -441,7 +442,7 @@ xfae_item_new (const gchar *relpath)
                   if (G_LIKELY (*args != NULL))
                     {
                       icon_name = g_path_get_basename (*args);
-                      item->icon = xfce_themed_icon_load (icon_name, 16);
+                      item->icon = gtk_icon_theme_load_icon (icon_theme, icon_name, 16, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
                       g_free (icon_name);
                     }
                   g_strfreev (args);
@@ -505,6 +506,9 @@ xfae_item_new (const gchar *relpath)
 static void
 xfae_item_free (XfaeItem *item)
 {
+  if (G_UNLIKELY (item == NULL))
+    return;
+
   if (item->icon != NULL)
     g_object_unref (G_OBJECT (item->icon));
 
@@ -625,6 +629,7 @@ xfae_model_add (XfaeModel   *model,
       file = (n == 0)
         ?  g_strdup_printf ("%s.desktop", name)
         : g_strdup_printf ("%s-%u.desktop", name, n);
+      file = g_strdelimit (file, G_DIR_SEPARATOR_S, '-'); /* not a copy */
 
       g_snprintf (relpath, 4096, "%s%s", dir, file);
       if (!g_file_test (relpath, G_FILE_TEST_IS_REGULAR))
@@ -686,6 +691,68 @@ xfae_model_add (XfaeModel   *model,
 
 
 
+/**
+ * xfae_model_get:
+ * @model       : a #XfaeModel.
+ * @name        : the user visible name of the new item.
+ * @description : the description for the new item.
+ * @command     : the command for the new item.
+ * @error       : return locations for errors or %NULL.
+ *
+ * Attempts to add a new item with the given parameters
+ * to @model.
+ *
+ * Return value: %TRUE if successfull, else %FALSE.
+ **/
+gboolean
+xfae_model_get (XfaeModel    *model,
+                GtkTreeIter  *iter,
+                gchar       **name,
+                gchar       **description,
+                gchar       **command,
+                GError      **error)
+{
+  XfaeItem    *item;
+  GList       *lp;
+  XfceRc      *rc;
+  const gchar *value;
+
+  g_return_val_if_fail (XFAE_IS_MODEL (model), FALSE);
+  g_return_val_if_fail (iter->stamp == model->stamp, FALSE);
+  g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+
+  lp = iter->user_data;
+  item = lp->data;
+
+  /* try to open the resource config */
+  rc = xfce_rc_config_open (XFCE_RESOURCE_CONFIG, item->relpath, FALSE);
+  if (G_UNLIKELY (rc == NULL))
+    {
+      g_set_error (error, G_FILE_ERROR, g_file_error_from_errno (EIO),
+                   _("Failed to open %s for reading"), item->relpath);
+      return FALSE;
+    }
+
+  /* read the resource config */
+  value = xfce_rc_read_entry (rc, "Name", NULL);
+  if (name != NULL)
+   *name = g_strdup (value);
+
+  value = xfce_rc_read_entry (rc, "Comment", NULL);
+  if (description != NULL)
+    *description = g_strdup (value);
+
+  value = xfce_rc_read_entry (rc, "Exec", NULL);
+  if (command != NULL)
+    *command = g_strdup (value);
+
+  xfce_rc_close (rc);
+
+  return TRUE;
+}
+
+
+
 /**
  * xfae_model_remove:
  * @model : a #XfaeModel.
@@ -704,7 +771,7 @@ xfae_model_remove (XfaeModel   *model,
   GtkTreePath *path;
   XfaeItem    *item;
   GList       *lp;
-  gint         index;
+  gint         index_;
 
   g_return_val_if_fail (XFAE_IS_MODEL (model), FALSE);
   g_return_val_if_fail (iter->stamp == model->stamp, FALSE);
@@ -718,12 +785,12 @@ xfae_model_remove (XfaeModel   *model,
     return FALSE;
 
   /* unlink the item from the list */
-  index = g_list_position (model->items, lp);
+  index_ = g_list_position (model->items, lp);
   model->items = g_list_delete_link (model->items, lp);
   xfae_item_free (item);
 
   /* tell the view that we have just removed one item */
-  path = gtk_tree_path_new_from_indices (index, -1);
+  path = gtk_tree_path_new_from_indices (index_, -1);
   gtk_tree_model_row_deleted (GTK_TREE_MODEL (model), path);
   gtk_tree_path_free (path);
 
@@ -732,6 +799,70 @@ xfae_model_remove (XfaeModel   *model,
 
 
 
+/**
+ * xfae_model_edit:
+ * @model       : a #XfaeModel.
+ * @iter        : the #GtkTreeIter referring to the item that should be removed.
+ * @name        : the user visible name of the new item.
+ * @description : the description for the new item.
+ * @command     : the command for the new item.
+ * @error       : return locations for errors or %NULL.
+ *
+ * Attempts to edit an item with the given parameters
+ * to @model.
+ *
+ * Return value: %TRUE if successfull, else %FALSE.
+ **/
+gboolean
+xfae_model_edit (XfaeModel   *model,
+                 GtkTreeIter *iter,
+                 const gchar *name,
+                 const gchar *description,
+                 const gchar *command,
+                 GError     **error)
+{
+  GtkTreePath *path;
+  XfaeItem    *item;
+  XfceRc      *rc;
+  GList       *lp;
+
+  g_return_val_if_fail (XFAE_IS_MODEL (model), FALSE);
+  g_return_val_if_fail (iter->stamp == model->stamp, FALSE);
+  g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+
+  lp = iter->user_data;
+  item = lp->data;
+
+  /* try to open the resource config */
+  rc = xfce_rc_config_open (XFCE_RESOURCE_CONFIG, item->relpath, FALSE);
+  if (G_UNLIKELY (rc == NULL))
+    {
+      g_set_error (error, G_FILE_ERROR, g_file_error_from_errno (EIO),
+                   _("Failed to open %s for writing"), item->relpath);
+      return FALSE;
+    }
+
+  item->name = g_strdup (name);
+  item->comment = g_strdup (description);
+
+  /* write the result */
+  xfce_rc_set_group (rc, "Desktop Entry");
+  xfce_rc_write_entry (rc, "Name", name);
+  xfce_rc_write_entry (rc, "Comment", description);
+  xfce_rc_write_entry (rc, "Exec", command);
+  xfce_rc_close (rc);
+
+  /* tell the view that we have most probably a new state */
+  path = gtk_tree_path_new_from_indices (g_list_position (model->items, lp), -1);
+  gtk_tree_model_row_changed (GTK_TREE_MODEL (model), path, iter);
+  gtk_tree_path_free (path);
+
+  return TRUE;
+}
+
+
+
+
 /**
  * xfae_model_toggle:
  * @model : a #XfaeModel.
